@@ -66,6 +66,9 @@
 #'   Set of required packages.
 #'   Note that these packages will be loaded via [requireNamespace()], and are not attached.
 #'
+#' * `man` :: `character(1)`\cr
+#'   String in the format `[pkg]::[topic]` pointing to a manual page for this object.
+#'
 #' @section Fields:
 #' * `id` :: `character(1)`\cr
 #'   Identifier of the learner.
@@ -142,10 +145,17 @@
 #'   Uses the data stored during `$train()` in `$state` to create a new [Prediction] based on the provided `row_ids`
 #'   of the `task`.
 #'
-#' * `predict_newdata(task, newdata)`\cr
-#'   ([Task], `data.frame()`) -> [Prediction]\cr
-#'   Uses the data stored during `$train()` in `$state` to create a new [Prediction] based on the new data in `newdata`.
+#' * `predict_newdata(newdata, task = NULL)`\cr
+#'   (`data.frame()`, [Task]) -> [Prediction]\cr
+#'   Uses the model fitted during `$train()` in to create a new [Prediction] based on the new data in `newdata`.
 #'   Object `task` is the task used during `$train()` and required for conversions of `newdata`.
+#'   If the learner's `$train()` method has been called, there is a (size reduced) version of the training task stored in the learner.
+#'   If the learner has been fitted via [resample()] or [benchmark()], you need to pass the corresponding task stored
+#'   in the [ResampleResult] or [BenchmarkResult], respectively.
+#'
+#' * `help()`\cr
+#'   () -> `NULL`\cr
+#'   Opens the corresponding help page referenced by `$man`.
 #'
 #' @section Optional Extractors:
 #'
@@ -202,9 +212,10 @@ Learner = R6Class("Learner",
     packages = NULL,
     predict_sets = "test",
     fallback = NULL,
+    man = NULL,
 
-    initialize = function(id, task_type, param_set = ParamSet$new(), predict_types = character(),
-      feature_types = character(), properties = character(), data_formats = "data.table", packages = character()) {
+    initialize = function(id, task_type, param_set = ParamSet$new(), predict_types = character(), feature_types = character(),
+      properties = character(), data_formats = "data.table", packages = character(), man = NA_character_) {
 
       self$id = assert_string(id, min.chars = 1L)
       self$task_type = assert_choice(task_type, mlr_reflections$task_types$type)
@@ -213,9 +224,14 @@ Learner = R6Class("Learner",
       self$feature_types = assert_subset(feature_types, mlr_reflections$task_feature_types)
       self$predict_types = assert_subset(predict_types, names(mlr_reflections$learner_predict_types[[task_type]]), empty.ok = FALSE)
       private$.predict_type = predict_types[1L]
-      self$packages = assert_set(packages)
       self$properties = sort(assert_subset(properties, mlr_reflections$learner_properties[[task_type]]))
       self$data_formats = assert_subset(data_formats, mlr_reflections$data_formats)
+      self$packages = assert_set(packages)
+      self$man = assert_string(man, na.ok = TRUE)
+    },
+
+    help = function() {
+      open_help(self$man)
     },
 
     format = function() {
@@ -231,28 +247,44 @@ Learner = R6Class("Learner",
       if (!is.null(row_ids)) {
         row_ids = assert_row_ids(row_ids)
       }
-      invisible(learner_train(self, task, row_ids))
+      learner_train(self, task, row_ids)
+
+      # store the task w/o the data
+      self$state$train_task = task_rm_data(task$clone(deep = TRUE))
+
+      invisible(self)
     },
 
     predict = function(task, row_ids = NULL) {
       task = assert_task(as_task(task), task_type = self$task_type, feature_types = self$feature_types)
+
       if (!is.null(row_ids)) {
         row_ids = assert_row_ids(row_ids)
       }
+
+      if (is.null(self$model) && is.null(self$state$fallback_state$model)) {
+        stopf("Cannot predict, Learner '%s' has not been trained yet", self$id)
+      }
+
       learner_predict(self, task, row_ids)
     },
 
-    predict_newdata = function(task, newdata) {
-      task = assert_task(as_task(task), task_type = self$task_type, feature_types = self$feature_types)
-      assert_data_frame(newdata, min.rows = 1L)
+    predict_newdata = function(newdata, task = NULL) {
+      if (is.null(task)) {
+        if (is.null(self$state$train_task))
+          stopf("No task stored, and no task provided")
+        task = self$state$train_task$clone()
+      } else {
+        task = assert_task(as_task(task, clone = TRUE), task_type = self$task_type, feature_types = self$feature_types)
+        task = task_rm_data(task)
+      }
+
+      newdata = assert_data_frame(newdata, min.rows = 1L)
       tn = task$target_names
       if (any(tn %nin% colnames(newdata))) {
         newdata[, tn] = NA
       }
-      old_row_ids = task$row_ids
-      task = task$clone(deep = TRUE)$rbind(newdata)
-      row_ids = setdiff(task$row_ids, old_row_ids)
-      self$predict(task, row_ids)
+      self$predict(task$rbind(newdata))
     }
   ),
 
