@@ -10,8 +10,8 @@
 #'
 #' @section Construction:
 #' ```
-#' m = MeasureRegr$new(id, range, minimize = NA, aggregator = NULL, properties = character(),
-#'      predict_type = "response", task_properties = character(), packages = character())
+#' m = MeasureRegr$new(id, range, minimize = NA, aggregator = NULL, properties = character(), predict_type = "response",
+#'     predict_sets = "test", task_properties = character(), packages = character())
 #' ```
 #' For a description of the arguments, see [Measure].
 #' The `task_type` is set to `"regr"`.
@@ -29,9 +29,11 @@
 #' @export
 MeasureRegr = R6Class("MeasureRegr", inherit = Measure, cloneable = FALSE,
   public = list(
-    initialize = function(id, range, minimize = NA, aggregator = NULL, properties = character(), predict_type = "response", task_properties = character(), packages = character()) {
+    initialize = function(id, range, minimize = NA, aggregator = NULL, properties = character(), predict_type = "response",
+      predict_sets = "test", task_properties = character(), packages = character(), man = NA_character_) {
       super$initialize(id, task_type = "regr", range = range, minimize = minimize, aggregator = aggregator,
-        properties = properties, predict_type = predict_type, task_properties = task_properties, packages = packages)
+        properties = properties, predict_type = predict_type, predict_sets = predict_sets,
+        task_properties = task_properties, packages = packages)
     }
   )
 )
