@@ -28,17 +28,16 @@
 #' Columns have been renamed. Preprocessed data taken from the \CRANpkg{kernlab} package.
 #'
 #' @references
-#' Dua, D. and Graff, C. (2019).
-#' \emph{UCI Machine Learning Repository} \url{http://archive.ics.uci.edu/ml}.
-#' Irvine, CA: University of California, School of Information and Computer Science.
+#' \cite{mlr3}{dua_2017}
 #'
 #' @template seealso_task
 NULL
 
 load_task_spam = function(id = "spam") {
   b = as_data_backend(readRDS(system.file("extdata", "spam.rds", package = "mlr3")))
-  b$hash = "_mlr3_tasks_spam_"
-  TaskClassif$new(id, b, target = "type", positive = "spam")
+  task = TaskClassif$new(id, b, target = "type", positive = "spam")
+  b$hash = task$man = "mlr3::mlr_tasks_spam"
+  task
 }
 
 #' @include mlr_tasks.R
