@@ -27,7 +27,7 @@ TaskGeneratorFriedman1 = R6Class("TaskGeneratorFriedman1",
         ParamDbl$new("sd", lower = 0L, default = 1)
       ))
 
-      super$initialize(id = "friedman1", "regr", "mlbench", ps)
+      super$initialize(id = "friedman1", "regr", "mlbench", ps, man = "mlr3::mlr_task_generators_friedman1")
     }
   ),
 
