@@ -1,50 +1,77 @@
 #' @include mlr_reflections.R
 
-task_set_row_role = function(self, rows, new_roles, exclusive = TRUE) {
+# old, deprecated, will be removed soon
+task_set_row_role = function(self, private, rows, new_roles, exclusive = TRUE) {
   rows = assert_row_ids(rows, type = typeof(self$row_roles$use))
   assert_subset(rows, self$backend$rownames)
   assert_subset(new_roles, mlr_reflections$task_row_roles)
   assert_flag(exclusive)
 
   for (role in new_roles) {
-    self$row_roles[[role]] = union(self$row_roles[[role]], rows)
+    private$.row_roles[[role]] = union(private$.row_roles[[role]], rows)
   }
 
   if (exclusive) {
     for (role in setdiff(names(self$row_roles), new_roles)) {
-      self$row_roles[[role]] = setdiff(self$row_roles[[role]], rows)
+      private$.row_roles[[role]] = setdiff(private$.row_roles[[role]], rows)
     }
   }
 }
 
-task_set_col_role = function(self, cols, new_roles, exclusive = TRUE) {
-
+# old, deprecated, will be removed soon
+task_set_col_role = function(self, private, cols, new_roles, exclusive = TRUE) {
   assert_character(cols, any.missing = FALSE)
   assert_subset(cols, self$col_info$id)
   assert_subset(new_roles, mlr_reflections$task_col_roles[[self$task_type]])
   assert_flag(exclusive)
 
+  col_roles = self$col_roles
+
   for (role in new_roles) {
-    self$col_roles[[role]] = union(self$col_roles[[role]], cols)
+    col_roles[[role]] = union(col_roles[[role]], cols)
   }
 
   if (exclusive) {
-    for (role in setdiff(names(self$col_roles), new_roles)) {
-      self$col_roles[[role]] = setdiff(self$col_roles[[role]], cols)
+    for (role in setdiff(names(col_roles), new_roles)) {
+      col_roles[[role]] = setdiff(col_roles[[role]], cols)
     }
   }
 
-  # update weights and groups property
-  for (role in c("weights", "groups")) {
-    n = length(self$col_roles[[role]])
-    if (n == 0L) {
-      self$properties = setdiff(self$properties, role)
-    } else if (n == 1L) {
-      self$properties = union(self$properties, role)
-    } else {
+  if (inherits(self, "TaskSupervised") && length(col_roles[["target"]]) == 0L) {
+    stopf("Supervised tasks need a target column")
+  }
+
+  for (role in c("group", "weight")) {
+    if (length(col_roles[[role]]) > 1L)
       stopf("Multiple columns with role '%s' not supported", role)
+  }
+
+  role = c("stratum", "group", "weight")
+  property = c("strata", "groups", "weights")
+  for (i in seq_along(role)) {
+    n = length(col_roles[[role[i]]])
+    if (n == 0L) {
+      private$.properties = setdiff(private$.properties, property[i])
+    } else if (n == 1L) {
+      private$.properties = union(private$.properties, property[i])
     }
   }
+
+  self$col_roles = col_roles
+}
+
+task_set_col_roles = function(self, private, roles) {
+    if (length(roles$group) > 1L) {
+      stopf("There may only be up to one group column")
+    }
+    if (length(roles$weight) > 1L) {
+      stopf("There may only be up to one weight column")
+    }
+    if (inherits(self, "TaskSupervised") && length(roles$target) == 0L) {
+      stopf("Supervised tasks need at least one target column")
+    }
+
+    private$.col_roles = roles
 }
 
 check_new_row_ids = function(task, data, type) {
@@ -118,7 +145,7 @@ task_rbind = function(self, data) {
   } else {
     rids = self$row_ids
     if (is.integer(rids)) {
-      data[[pk]] = max(rids) + seq_row(data)
+      data[[pk]] = (if (length(rids)) max(rids) else 0L) + seq_row(data)
     } else {
       data[[pk]] = sprintf("%s_%i", basename(tempfile("rbind_")), seq_row(data))
     }
@@ -190,7 +217,7 @@ task_cbind = function(self, data) {
   self$col_info = ujoin(self$col_info, ci, key = "id")
   self$col_info = rbind(self$col_info, ci[!list(self$col_info$id), on = "id"])
   setkeyv(self$col_info, "id")
-  self$col_roles$feature = union(self$col_roles$feature, setdiff(names(data), pk))
+  self$col_roles$feature = setdiff(union(self$col_roles$feature, names(data)), c(pk, self$col_roles$target))
 
   invisible(self)
 }
