@@ -3,14 +3,7 @@
 # Exceptions here are possibly encapsulated, so that they get captured
 # and turned into log messages.
 train_wrapper = function(learner, task) {
-  tryCatch({
-    model = learner$train_internal(task = task)
-  },
-  error = function(e) {
-    e$message = sprintf("Learner '%s' on task '%s' failed to fit: %s", learner$id, task$id, e$message)
-    stop(e)
-  }
-  )
+  model = learner$train_internal(task = task)
 
   if (is.null(model)) {
     stopf("Learner '%s' on task '%s' returned NULL during train_internal()", learner$id, task$id)
@@ -24,29 +17,17 @@ train_wrapper = function(learner, task) {
 # checks that the prediction was successful.
 # Exceptions here are possibly encapsulated, so that they get captured and turned into log messages.
 predict_wrapper = function(task, learner) {
-
   if (is.null(learner$state$model)) {
     stopf("No trained model available for learner '%s' on task '%s'", learner$id, task$id)
   }
 
-  result = tryCatch(
-    learner$predict_internal(task = task),
-    error = function(e) {
-      e$message = sprintf("Learner '%s' on task '%s' failed to predict: %s", learner$id, task$id, e$message)
-      stop(e)
-    }
-  )
+  result = learner$predict_internal(task = task)
 
   if (!inherits(result, "Prediction")) {
     stopf("Learner '%s' on task '%s' did not return a Prediction object, but instead: %s",
       learner$id, task$id, as_short_string(result))
   }
 
-  # unsupported = setdiff(names(result$data), c("row_ids", "truth", learner$predict_types))
-  # if (length(unsupported)) {
-  #   stopf("Learner '%s' on task '%s' returned result for unsupported predict type '%s'", learner$id, task$id, head(unsupported, 1L))
-  # }
-
   return(result)
 }
 
@@ -64,6 +45,8 @@ learner_train = function(learner, task, row_ids = NULL) {
     task$row_roles$use = row_ids
   }
 
+  learner$state = list()
+
   # call train_wrapper with encapsulation
   result = encapsulate(learner$encapsulate["train"],
     .f = train_wrapper,
@@ -76,11 +59,11 @@ learner_train = function(learner, task, row_ids = NULL) {
     lg$debug("Learner '%s' on task '%s' did not fit a model", learner$id, task$id, learner = learner$clone(), task = task$clone())
   }
 
-  learner$state = list(
+  learner$state = insert_named(learner$state, list(
     model = result$result,
     log = append_log(NULL, "train", result$log$class, result$log$msg),
     train_time = result$elapsed
-  )
+  ))
 
   # fit fallback learner
   fb = learner$fallback
